@@ -1,20 +1,8 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2007 Matthias Kretz <kretz@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2007 Matthias Kretz <kretz@kde.org>
 
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KCMULTIDIALOG_P_H
@@ -32,11 +20,14 @@ class KCMultiDialogPrivate
     Q_DECLARE_PUBLIC(KCMultiDialog)
 protected:
     KCMultiDialogPrivate(KCMultiDialog *parent)
-        : currentModule(nullptr), q_ptr(parent)
+        : currentModule(nullptr)
+        , q_ptr(parent)
     {
     }
 
-    virtual ~KCMultiDialogPrivate() {}
+    virtual ~KCMultiDialogPrivate()
+    {
+    }
 
     KCModuleProxy *currentModule;
 
@@ -55,6 +46,7 @@ protected:
     void _k_updateHeader(bool use, const QString &message);
 
     KCMultiDialog *q_ptr;
+
 private:
     void init();
     void apply();
