@@ -1,42 +1,29 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2007 Matthias Kretz <kretz@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2007 Matthias Kretz <kretz@kde.org>
 
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KSETTINGS_DIALOG_P_H
 #define KSETTINGS_DIALOG_P_H
 
-#include "dialog.h"
-#include "../kcmultidialog_p.h"
 #include "../kcmoduleinfo.h"
+#include "../kcmultidialog_p.h"
+#include "dialog.h"
 
 #include <QHash>
 #include <QSet>
 #include <QString>
 
-#include <kpagewidgetmodel.h>
-#include <kservice.h>
-#include <kplugininfo.h>
+#include <KPageWidgetModel>
+#include <KPluginInfo>
+#include <KService>
 
 class QCheckBox;
 
 namespace KSettings
 {
-
 class DialogPrivate : public KCMultiDialogPrivate
 {
     friend class PageNode;
@@ -59,18 +46,14 @@ protected:
     bool firstshow : 1;
     quint32 pluginStateDirty : 30;
 
-    //void _k_configureTree();
+    // void _k_configureTree();
     void _k_updateEnabledState(bool);
-    void _k_syncConfiguration();
-    void _k_reparseConfiguration(const QByteArray &a);
+    void updateConfiguration();
     void _k_clientChanged() override;
 
-    KPageWidgetItem *createPageItem(KPageWidgetItem *parentItem,
-                                    const QString &name, const QString &comment,
-                                    const QString &iconName, int weight);
+    KPageWidgetItem *createPageItem(KPageWidgetItem *parentItem, const QString &name, const QString &comment, const QString &iconName, int weight);
 
-    void connectItemCheckBox(KPageWidgetItem *item, const KPluginInfo &pinfo,
-                             bool isEnabled);
+    void connectItemCheckBox(KPageWidgetItem *item, const KPluginInfo &pinfo, bool isEnabled);
 
 private:
     /**
@@ -94,7 +77,7 @@ private:
      * If this module is put into a TreeList hierarchy this will return a
      * list of the names of the parent modules.
      */
-    //QStringList parentModuleNames(KCModuleInfo *);
+    // QStringList parentModuleNames(KCModuleInfo *);
 
     /**
      * @internal
